@@ -15,12 +15,14 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 
+TODO: Support inheritance with __slots__
+
 :license: Apache License 2.0
-:version: 0.1.6
+:version: 0.1.7
 """
 
 # Module version
-__version_info__ = (0, 1, 6)
+__version_info__ = (0, 1, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -55,7 +57,7 @@ class TranslationError(Exception):
 
 # ------------------------------------------------------------------------------
 
-def dump(obj, serialize_method=None, ignore_attribute=None, ignore=[],
+def dump(obj, serialize_method=None, ignore_attribute=None, ignore=None,
          config=jsonrpclib.config.DEFAULT):
     """
     Transforms the given object into a JSON-RPC compliant form.
@@ -76,9 +78,17 @@ def dump(obj, serialize_method=None, ignore_attribute=None, ignore=[],
     if not ignore_attribute:
         ignore_attribute = config.ignore_attribute
 
+    if not ignore:
+        ignore = []
+
     # Parse / return default "types"...
+    # Apply additional types, override built-in types
+    if isinstance(obj, tuple(config.serialize_handlers.keys())):
+        return config.serialize_handlers[type(obj)](obj, serialize_method,
+                                                    ignore_attribute, ignore)
+
     # Primitive
-    if isinstance(obj, utils.primitive_types):
+    elif isinstance(obj, utils.primitive_types):
         return obj
 
     # Iterative
@@ -101,7 +111,7 @@ def dump(obj, serialize_method=None, ignore_attribute=None, ignore=[],
         json_class = '{0}.{1}'.format(module_name, json_class)
 
     # Keep the class name in the returned object
-    return_obj = {"__jsonclass__": [json_class, ]}
+    return_obj = {"__jsonclass__": [json_class]}
 
     # If a serialization method is defined..
     if serialize_method in dir(obj):
@@ -120,8 +130,12 @@ def dump(obj, serialize_method=None, ignore_attribute=None, ignore=[],
         return_obj['__jsonclass__'].append([])
         attrs = {}
         ignore_list = getattr(obj, ignore_attribute, []) + ignore
-        for attr_name, attr_value in obj.__dict__.items():
-            if isinstance(attr_value, supported_types) and \
+        props = getattr(obj, "__dict__", {})
+        if hasattr(obj, "__slots__"):
+            props.update(((k, getattr(obj, k)) for k in obj.__slots__))
+        known_types = supported_types + tuple(config.serialize_handlers)
+        for attr_name, attr_value in props.items():
+            if isinstance(attr_value, known_types) and \
                     attr_name not in ignore_list and \
                     attr_value not in ignore_list:
                 attrs[attr_name] = dump(attr_value, serialize_method,
